@@ -271,5 +271,5 @@ class SQLAlchemyDistillery(Distillery):
     @classmethod
     def save(cls, instance):
         cls.__session__.add(instance)
-        cls.__session__.commit()
+        cls.__session__.flush()
         return instance
